@@ -47,7 +47,7 @@ HtmlGenerator::HtmlGenerator () :
     attachAnchors ( false ),
     anchorPrefix ( "l" )
 {
-    spacer = " ";
+    spacer = initialSpacer = " ";
     styleCommentOpen="/*";
     styleCommentClose="*/";
 }
@@ -213,12 +213,12 @@ string HtmlGenerator::getGeneratorComment()
 {
     ostringstream s;
     s << "\n</body>\n</html>\n";
-    
+
     if (!omitVersionComment) {
         s << "<!--HTML generated by highlight "
-          << HIGHLIGHT_VERSION << ", " <<  HIGHLIGHT_URL <<"-->\n";     
+          << HIGHLIGHT_VERSION << ", " <<  HIGHLIGHT_URL <<"-->\n";
     }
-   
+
     return s.str();
 }
 
@@ -227,7 +227,7 @@ string HtmlGenerator::getStyleDefinition()
     if (disableStyleCache || styleDefinitionCache.empty() ) {
         bool quoteFont=getBaseFont().find_first_of(",'")==string::npos;
         ostringstream os;
-        
+
         os << "/* highlight theme: "<<docStyle.getDescription()<<" */\n";
 
         string classNameSuffix;
@@ -416,7 +416,7 @@ bool HtmlGenerator::printIndexFile ( const vector<string> &fileList,
         indexfile << "</head>\n<body>\n<h1>Source Index</h1>\n"
                   << hrTag
                   <<  "\n<ul>\n";
-                  
+
         string::size_type pos;
         for ( unsigned int i=0; i < fileList.size();  i++ ) {
             pos= ( fileList[i] ).find_last_of ( Platform::pathSeparator );
